"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeSchemaCodec = exports.encodeRepo = void 0;
const core_1 = require("../../core");
const util_1 = require("../../util");
const versioned_1 = require("../versioned");
const format_1 = require("./format");
function encodeRepo(repo) {
    const treeNodeSchema = [];
    const rootFieldSchema = (0, core_1.encodeFieldSchema)(repo.rootFieldSchema);
    for (const [name, schema] of repo.nodeSchema) {
        treeNodeSchema.push(encodeTree(name, schema));
    }
    treeNodeSchema.sort(util_1.compareNamed);
    return {
        version: core_1.schemaFormat.version,
        nodeSchema: treeNodeSchema,
        rootFieldSchema,
    };
}
exports.encodeRepo = encodeRepo;
function encodeTree(name, schema) {
    const out = {
        name,
        data: (0, util_1.fromErased)(schema.encode()),
    };
    return out;
}
function decodeTree(schema) {
    return core_1.storedSchemaDecodeDispatcher.dispatch(schema.data);
}
function decode(f) {
    const nodeSchema = new Map();
    for (const tree of f.nodeSchema) {
        nodeSchema.set((0, util_1.brand)(tree.name), decodeTree(tree));
    }
    return {
        rootFieldSchema: (0, core_1.decodeFieldSchema)(f.rootFieldSchema),
        nodeSchema,
    };
}
/**
 * Creates a codec which performs synchronous monolithic encoding of schema content.
 */
function makeSchemaCodec(options) {
    return (0, versioned_1.makeVersionedValidatedCodec)(options, new Set([core_1.schemaFormat.version]), format_1.Format, {
        encode: (data) => encodeRepo(data),
        decode: (data) => decode(data),
    });
}
exports.makeSchemaCodec = makeSchemaCodec;
//# sourceMappingURL=codec.js.map