/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { Static } from "@sinclair/typebox";
import { schemaFormat } from "../../core";
export declare const TreeNodeSchemaFormat: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TUnsafe<schemaFormat.TreeNodeSchemaIdentifier<string>>;
    data: import("@sinclair/typebox").TObject<{
        object: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
            name: import("@sinclair/typebox").TUnsafe<schemaFormat.FieldKey>;
            kind: import("@sinclair/typebox").TUnsafe<schemaFormat.FieldKindIdentifier>;
            types: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TUnsafe<schemaFormat.TreeNodeSchemaIdentifier<string>>>>;
        }>>>;
        map: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TObject<{
            kind: import("@sinclair/typebox").TUnsafe<schemaFormat.FieldKindIdentifier>;
            types: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TUnsafe<schemaFormat.TreeNodeSchemaIdentifier<string>>>>;
        }>>;
        leaf: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TEnum<typeof schemaFormat.PersistedValueSchema>>;
    }>;
}>;
/**
 * Format for encoding as json.
 *
 * For consistency all lists are sorted and undefined values are omitted.
 *
 * This chooses to use lists of named objects instead of maps:
 * this choice is somewhat arbitrary, but avoids user data being used as object keys,
 * which can sometimes be an issue (for example handling that for "__proto__" can require care).
 * It also makes it simpler to determinately sort by keys.
 */
export declare const Format: import("@sinclair/typebox").TObject<{
    version: import("@sinclair/typebox").TLiteral<1>;
    nodeSchema: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        name: import("@sinclair/typebox").TUnsafe<schemaFormat.TreeNodeSchemaIdentifier<string>>;
        data: import("@sinclair/typebox").TObject<{
            object: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
                name: import("@sinclair/typebox").TUnsafe<schemaFormat.FieldKey>;
                kind: import("@sinclair/typebox").TUnsafe<schemaFormat.FieldKindIdentifier>;
                types: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TUnsafe<schemaFormat.TreeNodeSchemaIdentifier<string>>>>;
            }>>>;
            map: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TObject<{
                kind: import("@sinclair/typebox").TUnsafe<schemaFormat.FieldKindIdentifier>;
                types: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TUnsafe<schemaFormat.TreeNodeSchemaIdentifier<string>>>>;
            }>>;
            leaf: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TEnum<typeof schemaFormat.PersistedValueSchema>>;
        }>;
    }>>;
    rootFieldSchema: import("@sinclair/typebox").TObject<{
        kind: import("@sinclair/typebox").TUnsafe<schemaFormat.FieldKindIdentifier>;
        types: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TUnsafe<schemaFormat.TreeNodeSchemaIdentifier<string>>>>;
    }>;
}>;
export type Format = Static<typeof Format>;
export type TreeNodeSchemaFormat = Static<typeof TreeNodeSchemaFormat>;
export declare const Versioned: import("@sinclair/typebox").TObject<{
    version: import("@sinclair/typebox").TString;
}>;
export type Versioned = Static<typeof Versioned>;
//# sourceMappingURL=format.d.ts.map