/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { schemaFormat, decodeFieldSchema, encodeFieldSchema, storedSchemaDecodeDispatcher, } from "../../core";
import { brand, compareNamed, fromErased } from "../../util";
import { makeVersionedValidatedCodec } from "../versioned";
import { Format } from "./format";
export function encodeRepo(repo) {
    const treeNodeSchema = [];
    const rootFieldSchema = encodeFieldSchema(repo.rootFieldSchema);
    for (const [name, schema] of repo.nodeSchema) {
        treeNodeSchema.push(encodeTree(name, schema));
    }
    treeNodeSchema.sort(compareNamed);
    return {
        version: schemaFormat.version,
        nodeSchema: treeNodeSchema,
        rootFieldSchema,
    };
}
function encodeTree(name, schema) {
    const out = {
        name,
        data: fromErased(schema.encode()),
    };
    return out;
}
function decodeTree(schema) {
    return storedSchemaDecodeDispatcher.dispatch(schema.data);
}
function decode(f) {
    const nodeSchema = new Map();
    for (const tree of f.nodeSchema) {
        nodeSchema.set(brand(tree.name), decodeTree(tree));
    }
    return {
        rootFieldSchema: decodeFieldSchema(f.rootFieldSchema),
        nodeSchema,
    };
}
/**
 * Creates a codec which performs synchronous monolithic encoding of schema content.
 */
export function makeSchemaCodec(options) {
    return makeVersionedValidatedCodec(options, new Set([schemaFormat.version]), Format, {
        encode: (data) => encodeRepo(data),
        decode: (data) => decode(data),
    });
}
//# sourceMappingURL=codec.js.map